@@ -9,7 +9,8 @@ CACHE_DIR_NAME = ".cache"
 TOML_EXTENSION = ".toml"
 NITPICK_STYLE_TOML = f"nitpick-style{TOML_EXTENSION}"
 MERGED_STYLE_TOML = f"merged-style{TOML_EXTENSION}"
-RAW_GITHUB_CONTENT_BASE_URL = f"https://raw.githubusercontent.com/andreoliwa/{PROJECT_NAME}"
+RAW_GITHUB_CONTENT_BASE_URL = f"https://raw.githubusercontent.com/andreoliwa/{PROJECT_NAME}/"
+GITHUB_BASE_URL = f"https://github.com/andreoliwa/{PROJECT_NAME}/blob/"
 READ_THE_DOCS_URL = "https://nitpick.rtfd.io/en/latest/"
 
 # Special files
@@ -19,6 +20,9 @@ ROOT_PYTHON_FILES = ("setup.py", "app.py", "wsgi.py", "autoapp.py")
 ROOT_FILES = (PYPROJECT_TOML, SETUP_CFG, "requirements*.txt", "Pipfile") + ROOT_PYTHON_FILES
 MANAGE_PY = "manage.py"
 PRE_COMMIT_CONFIG_YAML = ".pre-commit-config.yaml"
+EDITOR_CONFIG = ".editorconfig"
+TOX_INI = "tox.ini"
+PYLINTRC = ".pylintrc"
 
 SINGLE_QUOTE = "'"
 DOUBLE_QUOTE = '"'
