@@ -6,7 +6,7 @@ from marshmallow.fields import Dict, Field, List, Nested, String
 from marshmallow.validate import Length
 from more_itertools import always_iterable
 
-from nitpick.generic import pretty_exception
+from nitpick.exceptions import pretty_exception
 
 __all__ = ("Dict", "List", "String", "Nested", "Field")
 
@@ -54,17 +54,17 @@ def string_or_list_field(object_dict, parent_object_dict):  # pylint: disable=un
 
 
 def validate_section_dot_field(section_field: str) -> bool:
-    """Validate if the combinatio section/field has a dot separating them."""
+    """Validate if the combination section/field has a dot separating them."""
     common = "Use <section_name>.<field_name>"
     if "." not in section_field:
-        raise ValidationError("Dot is missing. {}".format(common))
+        raise ValidationError(f"Dot is missing. {common}")
     parts = section_field.split(".")
     if len(parts) > 2:
-        raise ValidationError("There's more than one dot. {}".format(common))
+        raise ValidationError(f"There's more than one dot. {common}")
     if not parts[0].strip():
-        raise ValidationError("Empty section name. {}".format(common))
+        raise ValidationError(f"Empty section name. {common}")
     if not parts[1].strip():
-        raise ValidationError("Empty field name. {}".format(common))
+        raise ValidationError(f"Empty field name. {common}")
     return True
 
 
