@@ -6,7 +6,6 @@
 """
 import re
 from collections import OrderedDict
-from functools import lru_cache
 from pathlib import Path
 from typing import Any, Dict, Iterable, List, MutableMapping, Optional, Tuple, Union
 
@@ -32,18 +31,11 @@ def flatten(dict_, parent_key="", separator=".", current_lists=None) -> JsonDict
     Use :py:meth:`unflatten()` to revert.
 
     Adapted from `this StackOverflow question <https://stackoverflow.com/a/6027615>`_.
-
-    >>> expected = {'root.sub1': 1, 'root.sub2.deep': 3, 'sibling': False}
-    >>> flatten({"root": {"sub1": 1, "sub2": {"deep": 3}}, "sibling": False}) == expected
-    True
-    >>> expected = {'parent."with.dot".again': True, 'parent."my.my"': 1, "parent.123": "numeric-key"}
-    >>> flatten({"parent": {"with.dot": {"again": True}, "my.my": 1, 123: "numeric-key"}}) == expected
-    True
     """
     if current_lists is None:
         current_lists = {}
 
-    items = []  # type: List[Tuple[str, Any]]
+    items: List[Tuple[str, Any]] = []
     for key, value in dict_.items():
         quoted_key = f"{DOUBLE_QUOTE}{key}{DOUBLE_QUOTE}" if separator in str(key) else key
         new_key = str(parent_key) + separator + str(quoted_key) if parent_key else quoted_key
@@ -230,7 +222,6 @@ def is_url(url: str) -> bool:
     return url.startswith("http")
 
 
-@lru_cache()
 def relative_to_current_dir(path_or_str: Optional[PathOrStr]) -> str:
     """Return a relative path to the current dir or an absolute path."""
     if not path_or_str:
@@ -238,7 +229,8 @@ def relative_to_current_dir(path_or_str: Optional[PathOrStr]) -> str:
 
     path = Path(path_or_str)
     if str(path).startswith(str(Path.cwd())):
-        return str(path.relative_to(Path.cwd())).lstrip(".")
+        rv = str(path.relative_to(Path.cwd()))
+        return "" if rv == "." else rv
 
     return str(path.absolute())
 
