@@ -1,6 +1,6 @@
 """Type definitions."""
 from pathlib import Path
-from typing import Any, Dict, Iterator, List, Tuple, Type, Union
+from typing import Any, Dict, List, Tuple, Type, Union
 
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
 
@@ -8,5 +8,8 @@ PathOrStr = Union[Path, str]
 JsonDict = Dict[str, Any]
 StrOrList = Union[str, List[str]]
 Flake8Error = Tuple[int, int, str, Type]
-YieldFlake8Error = Iterator[Flake8Error]
 YamlData = Union[CommentedSeq, CommentedMap]
+
+# Decorated property not supported · Issue #1362 · python/mypy
+# https://github.com/python/mypy/issues/1362#issuecomment-562141376
+mypy_property: Any = property
